@@ -2,6 +2,8 @@
 import asyncio
 import os
 import platform
+import pkg_resources
+import luddite
 import discord
 from discord.ext import commands
 from discord import app_commands
@@ -21,6 +23,9 @@ class SetupCog(commands.Cog):
     async def sync_command(self, context: commands.Context) -> None:
         """Add slash commands to Discord guid"""
         if platform.node().lower() == "secureerase":
+            await context.defer()
+            if pkg_resources.get_distribution("shiny_api") != luddite.get_version_pypi("shiny_api"):
+                quit()
             await asyncio.sleep(2)
 
         try:
@@ -36,8 +41,8 @@ class SetupCog(commands.Cog):
             else:
                 print("Switching to Dev")
                 await bot_member.add_roles(role)
-        except commands.errors.CommandInvokeError:
-            print("not able to delete")
+        except discord.errors.NotFound:
+            print("Not able to delete message")
             return
 
     @app_commands.command(name="clear")
